# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


MSC_PLANNING_API_ROUTE = 'pyams_msc.planning'
'''MSC planning API route'''


MSC_PLANNING_API_PATH = '/api/msc/planning'
'''MSC planning API default path'''


MSC_SESSION_API_ROUTE = 'pyams_msc.session'
'''MSC session API route'''


MSC_SESSION_API_PATH = '/api/msc/session/{session_id}'
'''MSC session API default path'''
