# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


MSC_BOOKING_SEARCH_API_ROUTE = 'pyams_msc.booking.search'
'''MSC booking search API route'''


MSC_BOOKING_SEARCH_API_PATH = '/api/msc/booking'
'''MSC booking search API path'''


MSC_BOOKING_API_ROUTE = 'pyams_msc.booking'
'''MSC booking API route'''


MSC_BOOKING_API_PATH = '/api/msc/booking/{booking_id}'
'''MSC booking API path'''


MSC_BOOKING_VALIDATION_API_ROUTE = 'pyams_msc.booking.validation'
'''MSC booking validation API route'''


MSC_BOOKING_VALIDATION_API_PATH = '/api/msc/booking/{booking_id}/validate'
'''MSC booking validation API path'''
